/**************************************************************************
**
**	FILE        :  @(#)56321evb.dsc	1.2
**
**	VERSION     :  01/10/19
**
**	DESCRIPTION :  Locator software part description 
**                     for Motorola DSP56321EVM.
**
**	COPYRIGHT   :  2001 TASKING, Inc.
**
**      NOTE        :  Values for the size of internal memory spaces are
**                     taken from the CPU file. By default this file
**                     assumes that the cache is switched on and the memory
**                     switch is off.
**
**		       Defines to change the default memory layout 
**		       (-em<define> on the locator command line):
**		       MEM_Y,
**		       MEM_P,
**                     MEM_L : Y/P/L used as default memory (instead of X)
**		       NSTK_L: do not put stack in L memory 
**			       (only applicable for default X or Y memory)
**		       STACKSIZE: set stack size (other than default)
**		       HEAPSIZE : set heap size (other than default)
**		       NEARXYSIZE : set near X/Y variable area size
**		       SESIZE   : set stack extension size
**
**************************************************************************/

#ifndef STACKSIZE
#ifdef 	NSTK_L
#define STACKSIZE 1024
#else	// NSTK_L
#define STACKSIZE 768
#endif	// NSTK_L
#endif	// STACKSIZE

#ifndef HEAPSIZE
#define HEAPSIZE  4096
#endif	// HEAPSIZE

#ifndef NEARXYSIZE
#define NEARXYSIZE 0
#endif	// NEARXYSIZE

#ifndef SESIZE
#define	SESIZE 1000
#endif	// SESIZE

#if	!defined( MEM_Y ) && !defined( MEM_P ) && !defined( MEM_L )
#define MEM_X
#endif	// !defined( MEM_Y ) && !defined( MEM_P ) && !defined( MEM_L )

software {
	layout {
		space P {
			// P address space
			block P_block {
				// P-space memory range 
				cluster P_clstr {
					attribute r;
					amode P_sjmp {
						// short jump addressing mode:
						// locate executable sections
						// locate read-only sections
						// locate data sections
						section selection=x;
						section selection=r;
						section selection=w;
					}
					amode P_far {
						// far addressing mode:
						// locate executable sections
						// locate read-only sections
						// locate copy table
						// locate rom copies
						// locate data sections
						section selection=x;
						section selection=r;
						table;
						copy;
						section selection=w;
#ifdef	MEM_P
						stack length = STACKSIZE;
						heap length = HEAPSIZE;	
#endif	// MEM_P
					}
				}
			}
		}
		space L {
			// L address space
			block L_block {
				// L-space memory range
				cluster L_clstr {
					attribute w;
					amode L_near {
						// near addressing mode:
						// locate writable sections
						section selection=w;
					}
					amode L_far {
						// far addressing mode:
						// locate writable sections
						reserved length=0 address=NEARXYSIZE;
#ifdef	MEM_L
						stack length = STACKSIZE;
						section selection=w;
						heap length = HEAPSIZE;	
#else	// MEM_L
#if 	!defined(NSTK_L) && !defined(MEM_P)
						stack length = STACKSIZE;
#endif	// !NSTK_L && !MEM_P
						section selection=w;
#endif	// MEM_L
					}
				}
			}
		}
		space X {
			// X address space
			block X_block {
				// X-space memory range
				cluster X_clstr {
					attribute w;
					amode X_near {
						// near addressing mode:
						// locate writable sections
						section selection=w;
					}
					amode X_far {
						// far addressing mode:
						// locate writable sections 
						// locate heap
						// locate stack
						// locate stack extension
#ifdef  MEM_X
#ifdef  NSTK_L
						stack length = STACKSIZE;
#endif	// NSTK_L
						section selection=w;
						heap length = HEAPSIZE;	
#else	// MEM_X
						section selection=w;
						reserved label=se length = SESIZE;
#endif	// MEM_X
					}
					amode X_io {
						// io addressing mode:
						// locate writable sections
						section selection=w;
					}
				}
			}
		}
		space Y {
			// Y address space
			block Y_block {
				// Y-space memory range
				cluster Y_clstr {
					attribute w;
					amode Y_near {
						// near addressing mode:
						// locate writable sections
						section selection=w;
					}
					amode Y_far {
						// far addressing mode:
						// locate writable sections
						// reserve for CrossView debugger:
						//            only when using '-g'
#ifdef	MEM_Y
#ifdef NSTK_L
						stack length = STACKSIZE;
#endif 	// NSTK_L
						section selection=w;
						heap length = HEAPSIZE;	
#else	// MEM_Y
						section selection=w;
						reserved label=se length = SESIZE;
#endif	// MEM_Y
						reserved label=xvwbuffer length=0x10;
					}
					amode Y_io {
						// io addressing mode:
						// locate writable sections
						section selection=w;
					}
				}
			}
		}
	}
}


// include cpu part and memory part
cpu 56321.cpu
memory 56321evb.mem
