/*
 *	@(#)reg56366.h	1.1 01/06/18
 */

/**************************************************************************
**									  *
**  FILE	:  reg56366.h						  *
**									  *
**  DESCRIPTION :  Include file with memory mapped I/O definitions	  *
**		   for the DSP56366.					  *
**									  *
**  COPYRIGHT	:  2001 TASKING, Inc.				  *
**									  *
**************************************************************************/

#ifndef _REG56366_H
#define _REG56366_H

#include <irq5636x.h>

/*--------------------------------------------------------------------------------

	PLL

--------------------------------------------------------------------------------*/

typedef union				/* PLL Control Register			*/
{
	struct
	{	unsigned MF  : 12; /*  0: Multiplication Factor			*/
		unsigned DF  : 3;  /* 12: Division Factor			*/
		int	 XTLR: 1;  /* 15: XTAL Range				*/
		int	 XTLD: 1;  /* 16: XTAL Disable				*/
		int	 PSTP: 1;  /* 17: STOP processing State			*/
		int	 PEN : 1;  /* 18: PLL Enable				*/
		int	 CODI: 1;  /* 19: Clock Output Disable			*/
		unsigned PPD : 4;  /* 20: PLL Predivider			*/
	} B;

	int I;

} pctl_type;

#define PCTL  (*(pctl_type _X*) 0xFFFFFD) /* PLL Control Register		*/


/*--------------------------------------------------------------------------------

	OnCE

--------------------------------------------------------------------------------*/


#define OGDBR  (*(int _X*)    	0xFFFFFC) /* OnCE GDB Register			*/


/*--------------------------------------------------------------------------------

	Port A

--------------------------------------------------------------------------------*/

typedef union				/* Port A Bus Control Register		*/
{
	struct
	{	unsigned BA0W: 5;  /*  0: Area 0 Waitstates			*/
		unsigned BA1W: 5;  /*  5: Area 1 Waitstates			*/
		unsigned BA2W: 3;  /* 10: Area 2 Waitstates			*/
		unsigned BA3W: 3;  /* 13: Area 3 Waitstates			*/
		unsigned BDFW: 5;  /* 16: Default Area Waitstates		*/
		int	 BBS : 1;  /* 21: Bus State				*/
		int	 BLH : 1;  /* 22: Bus Lock Hold				*/
		int	 BRH : 1;  /* 23: Bus Request Hold			*/
	} B;

	int I;

} bcr_type;


#define BCR   (*(volatile bcr_type _X*)	0xFFFFFB) /* Port A Bus Control Register	*/
#define DCR   (*(int _X*)    	0xFFFFFA) /* Port A DRAM Control Register	*/
#define AAR0  (*(int _X*)    	0xFFFFF9) /* Port A Address Attribute Register 0*/
#define AAR1  (*(int _X*)    	0xFFFFF8) /* Port A Address Attribute Register 1*/
#define AAR2  (*(int _X*)    	0xFFFFF7) /* Port A Address Attribute Register 2*/
#define AAR3  (*(int _X*)    	0xFFFFF6) /* Port A Address Attribute Register 3*/
#define IDR   (*(int _X*)    	0xFFFFF5) /* Port A ID Register			*/


/*--------------------------------------------------------------------------------

	DMA

--------------------------------------------------------------------------------*/

typedef union				/* DMA Status Register			*/
{
	struct
	{	int	 DTD0: 1;  /*  0: DMA Channel 0 Transfer Done Status	*/
		int	 DTD1: 1;  /*  1: DMA Channel 1 Transfer Done Status	*/
		int	 DTD2: 1;  /*  2: DMA Channel 2 Transfer Done Status	*/
		int	 DTD3: 1;  /*  3: DMA Channel 3 Transfer Done Status	*/
		int	 DTD4: 1;  /*  4: DMA Channel 4 Transfer Done Status	*/
		int	 DTD5: 1;  /*  5: DMA Channel 5 Transfer Done Status	*/
		unsigned     : 2;  /*  6: Reserved				*/
		int	 DACT: 1;  /*  8: DMA Active				*/
		unsigned DCH : 3;  /*  9: DMA Active Channel			*/
		unsigned     :12;  /* 12: Reserved				*/
	} B;

	int I;

} dstr_type;

typedef union				/* DMA Control Register			*/
{
	struct
	{	unsigned DSS : 2;  /*  0: DMA Source Space			*/
		unsigned DDS : 2;  /*  2: DMA Destination Space			*/
		unsigned DAM : 6;  /*  4: DMA Address Mode			*/
		int	 D3D : 1;  /* 10: DMA Three Dimensional Mode		*/
		unsigned DRS : 5;  /* 11: DMA Request Source			*/
		int	 DCON: 1;  /* 16: DMA Continuous Mode			*/
		unsigned DPR : 2;  /* 17: DMA Channel Priority			*/
		unsigned DTM : 3;  /* 19: DMA Transfer Mode			*/
		int	 DIE : 1;  /* 22: DMA Interrupt Enable			*/
		int	 DE  : 1;  /* 23: DMA Enable				*/
	} B;

	int I;

} dctrl_type;


#define DSTR  (*(volatile dstr_type _X*)0xFFFFF4) /* DMA Status Register	*/

#define DOR0  (*(int _X*)	  0xFFFFF3) /* DMA Offset Register 0		*/
#define DOR1  (*(int _X*)	  0xFFFFF2) /* DMA Offset Register 1		*/
#define DOR2  (*(int _X*)	  0xFFFFF1) /* DMA Offset Register 2		*/
#define DOR3  (*(int _X*)	  0xFFFFF0) /* DMA Offset Register 3		*/

#define DSR0 (*(int* volatile _X*)0xFFFFEF) /* DMA Source Address Reg. 0	*/
#define DDR0 (*(int* volatile _X*)0xFFFFEE) /* DMA Destination Address Reg. 0	*/
#define DCO0 (*(volatile int  _X*)0xFFFFED) /* DMA Counter 0			*/
#define DCR0 (*(dctrl_type _X*)   0xFFFFEC) /* DMA Control Register 0		*/

#define DSR1 (*(int* volatile _X*)0xFFFFEB) /* DMA Source Address Reg. 1	*/
#define DDR1 (*(int* volatile _X*)0xFFFFEA) /* DMA Destination Address Reg. 1	*/
#define DCO1 (*(volatile int  _X*)0xFFFFE9) /* DMA Counter 1			*/
#define DCR1 (*(dctrl_type _X*)   0xFFFFE8) /* DMA Control Register 1		*/

#define DSR2 (*(int* volatile _X*)0xFFFFE7) /* DMA Source Address Reg. 2	*/
#define DDR2 (*(int* volatile _X*)0xFFFFE6) /* DMA Destination Address Reg. 2	*/
#define DCO2 (*(volatile int  _X*)0xFFFFE5) /* DMA Counter 2			*/
#define DCR2 (*(dctrl_type _X*)   0xFFFFE4) /* DMA Control Register 2		*/

#define DSR3 (*(int* volatile _X*)0xFFFFE3) /* DMA Source Address Reg. 3	*/
#define DDR3 (*(int* volatile _X*)0xFFFFE2) /* DMA Destination Address Reg. 3	*/
#define DCO3 (*(volatile int  _X*)0xFFFFE1) /* DMA Counter 3			*/
#define DCR3 (*(dctrl_type _X*)   0xFFFFE0) /* DMA Control Register 3		*/

#define DSR4 (*(int* volatile _X*)0xFFFFDF) /* DMA Source Address Reg. 4	*/
#define DDR4 (*(int* volatile _X*)0xFFFFDE) /* DMA Destination Address Reg. 4	*/
#define DCO4 (*(volatile int  _X*)0xFFFFDD) /* DMA Counter 4			*/
#define DCR4 (*(dctrl_type _X*)   0xFFFFDC) /* DMA Control Register 4		*/

#define DSR5 (*(int* volatile _X*)0xFFFFDB) /* DMA Source Address Reg. 5	*/
#define DDR5 (*(int* volatile _X*)0xFFFFDA) /* DMA Destination Address Reg. 5	*/
#define DCO5 (*(volatile int  _X*)0xFFFFD9) /* DMA Counter 5			*/
#define DCR5 (*(dctrl_type _X*)   0xFFFFD8) /* DMA Control Register 5		*/


/*--------------------------------------------------------------------------------

	Host Interface HI08

--------------------------------------------------------------------------------*/

typedef union				 /* Host Control Register		*/
{
	struct
	{	int HRIE: 1;	/*  0: Host Receive Interrupt Enable		*/
		int HTIE: 1;	/*  1: Host Transmit Interrupt Enable		*/
		int HCIE: 1;	/*  2: Host Command Interrupt Enable		*/
		int HF2 : 1;	/*  3: Host Flag 2				*/
		int HF3 : 1;	/*  4: Host Flag 3				*/
		int HDM : 3;	/*  5: Host DMA Mode				*/
		int	: 8;	/*  8: Reserved					*/
	} B;

	int I;

} hcr_type;


typedef union				/* Host Status Register			*/
{
	struct
	{	int HRDF: 1;	/*  0: Host Receive Data Full			*/
		int HTDE: 1;	/*  1: Host Transmit Data Empty			*/
		int HCP : 1;	/*  2: Host Command Pending			*/
		int HF0 : 1;	/*  3: Host Flag 0				*/
		int HF1 : 1;	/*  4: Host Flag 1				*/
		int	: 2;	/*  5: Reserved					*/
		int DMA : 1;	/*  7: Host DMA Status				*/
		int	: 8;	/*  8: Reserved					*/
	} B;

	int I;

} hsr_type;

typedef union				 /* Host Port Control Register		*/
{
	struct
	{	int HGEN : 1;	/*  0: Host GPIO Port Enable			*/
		int HA8EN: 1;	/*  1: Host Address Line 8 Enable		*/
		int HA9EN: 1;	/*  2: Host Address Line 9 Enable		*/
		int HCSEN: 1;	/*  3: Host Chip Select Enable			*/
		int HREN : 1;	/*  4: Host Request Enable			*/
		int HAEN : 1;	/*  5: Host Acknowledge Enable			*/
		int HEN	 : 1;	/*  6: Host Enable				*/
		int	 : 1;	/*  7: Reserved					*/
		int HROD : 1;	/*  8: Host Request Open Drain			*/
		int HDSP : 1;	/*  9: Host Data Strobe Polarity		*/
		int HASP : 1;	/* 10: Host Address Strobe Polarity		*/
		int HMUX : 1;	/* 11: Host Multiplexed Bus			*/
		int HDDS : 1;	/* 12: Host Dual Data Strobe			*/
		int HCSP : 1;	/* 13: Host Chip Select Polarity		*/
		int HRP	 : 1;	/* 14: Host Request Polarity			*/
		int HAP	 : 1;	/* 15: Host Acknowledge Polarity		*/
	} B;

	int I;

} hpcr_type;


#define HDR   (*(volatile int _X*) 0xFFFFC9) /* Host GPIO Data Register		*/
#define HDDR  (*(int _X*)	   0xFFFFC8) /* Host GPIO Data Direction Reg.	*/
#define HTX   (*(volatile int _X*)	   0xFFFFC7) /* Host Data Transmit Reg. */
#define HRX   (*(const volatile int _X*)   0xFFFFC6) /* Host Data Receive Reg.  */
#define HBAR  (*(int _X*)	   	   0xFFFFC5) /* Host Base Address Reg.	*/
#define HPCR  (*(hpcr_type _X*)	           0xFFFFC4) /* Host Port Control Reg.	*/
#define HSR   (*(const volatile hsr_type _X*)0xFFFFC3) /* Host Status Register  */
#define HCR   (*(hcr_type _X*)		   0xFFFFC2) /* Host Control Register   */



/*--------------------------------------------------------------------------------

	Serial Host Interface

--------------------------------------------------------------------------------*/

typedef union				 /* SHI Clock Control Register		*/
{
	struct
	{	int	 CPHA: 1;  /*  0: SHI Clock Phase			*/
		int	 CPOL: 1;  /*  1: SHI Clock Polarity			*/
		int	 HRS : 1;  /*  2: SHI Clock Prescaler Rate Select	*/
		unsigned SHDM: 8;  /*  3: SHI Clock Divider Modulus Select	*/
		int	     : 1;  /* 11: Reserved				*/
		int HFM	     : 2;  /* 12: SHI Clock Filter Mode			*/
		int	     : 10; /* 14: Reserved				*/
	} B;

	int I;

} hckr_type;

typedef union				 /* SHI Control/Status Register		*/
{
	struct
	{	int	  SHEN: 1;  /*	0: Host Enable				*/
		int	 SHIIC: 1;  /*	1: I2C/SPI Selection			*/
		unsigned   SHM: 2;  /*	2: Serial Host Interface Mode		*/
		int	SHCKFR: 1;  /*	4: I2C Clock Freeze			*/
		int	SHFIFO: 1;  /*	5: FIFO-Enable Control			*/
		int	 SHMST: 1;  /*	6: Master Mode				*/
		unsigned SHRQE: 2;  /*	7: Host Request Enable			*/
		int	SHIDLE: 1;  /*	9: Idle					*/
		int	 SHBIE: 1;  /* 10: Bus Error Interrupt Enable		*/
		int	 SHTIE: 1;  /* 11: Transmit Interrupt Enable		*/
		unsigned SHRIE: 1;  /* 12: Receive Interrupt Enable		*/
		int	 SHTUE: 1;  /* 14: Transmit Underrun Error		*/
		int	 SHTDE: 1;  /* 15: Transmit Data Empty			*/
		int	      : 1;  /* 16: Reserved				*/
		int	 SHRNE: 1;  /* 17: Receive FIFO not empty		*/
		int	      : 1;  /* 18: Reserved				*/
		int	 SHRFF: 1;  /* 19: Receive FIFO full			*/
		int	 SHROE: 1;  /* 20: Receive Overrun Error		*/
		int	 SHBER: 1;  /* 21: Host Bus Error			*/
		int	SHBUSY: 1;  /* 22: Host Busy				*/
		int	      : 1;  /* 23: Reserved				*/
	} B;

	int I;

} hcsr_type;

typedef union				 /* SHI Slave Address Register		*/
{
	struct
	{	int	     : 18; /*  0: Reserved				*/
		int	 SHA1: 1;  /* 18: I2C Slave Address bit 1		*/
		int	     : 1 ; /* 19: Reserved				*/
		unsigned SHAx: 4;  /* 20: I2C Slave Address bit 3..6		*/
	} B;

	int I;

} hsar_type;

#define HCKR  (*(hckr_type _X*)		0xFFFF90) /* SHI Clock Control Reg.   	*/
#define HCSR  (*(volatile hcsr_type _X*)0xFFFF91) /* SHI Control/Status Reg.  	*/
#define HSAR  (*(volatile hsar_type _X*)0xFFFF92) /* SHI Slave Address Reg.   	*/
#define SHTX  (*(volatile int _X*)	0xFFFF93) /* SHI Transmit Data Reg.   	*/
#define SHRX  (*(const volatile int _X*)0xFFFF94) /* SHI Receive Data FIFO    	*/


/*--------------------------------------------------------------------------------

	Port C

--------------------------------------------------------------------------------*/

#define PCRC  (*(int _X*)   	  0xFFFFBF) /* Port C Control Register		*/
#define PRRC  (*(int _X*)   	  0xFFFFBE) /* Port C Direction Register	*/
#define PDRC  (*(volatile int _X*)0xFFFFBD) /* Port C GPIO Data Register	*/


/*--------------------------------------------------------------------------------

	ESAI

--------------------------------------------------------------------------------*/

typedef union				/* ESAI Transmit Clock Control Register */
{
	struct
	{	unsigned  TPM: 8;  /*  0: Prescale Modulus Select		*/
		int	 TPSR: 1;  /*  8: Prescale Range			*/
		unsigned  TDC: 5;  /*  9: Frame Rate Divider Control		*/
		unsigned  TFP: 4;  /* 14: High Frequency Clock Divider Control	*/
		int	 TCKP: 1;  /* 18: Transmitter Clock Polarity		*/
		int	 TFSP: 1;  /* 19: Transmitter Frame Sync Polarity	*/
		int	THCKP: 1;  /* 20: Transmitter HF Clock Polarity		*/
		int	 TCKD: 1;  /* 21: Transmitter Clock Source Direction	*/
		int	 TFSD: 1;  /* 22: Transmitter Frame Sync Signal Dir	*/
		int	THCKD: 1;  /* 23: HF Clock Direction			*/
	} B;

	int I;

} tccr_type;

typedef union				/* ESAI Transmit Control Register	*/
{
	struct
	{	int	  TE0: 1;  /*  0: Transmit #0 Enable			*/
		int	  TE1: 1;  /*  1: Transmit #1 Enable			*/
		int	  TE2: 1;  /*  2: Transmit #2 Enable			*/
		int	  TE3: 1;  /*  3: Transmit #3 Enable			*/
		int	  TE4: 1;  /*  4: Transmit #4 Enable			*/
		int	  TE5: 1;  /*  5: Transmit #5 Enable			*/
		int	TSHFD: 1;  /*  6: Transmitter Shift Direction		*/
		int	  TWA: 1;  /*  7: Transmitter Word Alignment Control	*/
		unsigned TMOD: 2;  /*  8: Transmitter Network Mode Control	*/
		unsigned TSWS: 5;  /* 10: Transmitter Slot and Word Length Sel. */
		int	 TFSL: 1;  /* 15: Transmitter Frame Sync Length		*/
		int	 TFSR: 1;  /* 16: Transmitter Frame Sync Rel. Timing	*/
		unsigned     : 3;  /* 17: Reserved				*/
		int	 TEIE: 1;  /* 20: Transmit Exception Interrupt Enable	*/
		int	TEDIE: 1;  /* 21: Transmit Even Slot Data Int. Enable	*/
		int	  TIE: 1;  /* 22: Transmit Interrupt Enable		*/
		int	 TLIE: 1;  /* 23: Transmit Last Slot Interrupt Enable	*/
	} B;

	int I;

} tcr_type;

typedef union				/* ESAI Receive Clock Control Register	*/
{
	struct
	{	unsigned  RPM: 8;  /*  0: Prescale Modulus Select		*/
		int	 RPSR: 1;  /*  8: Prescale Range			*/
		unsigned  RDC: 5;  /*  9: Frame Rate Divider Control		*/
		unsigned  RFP: 4;  /* 14: High Frequency Clock Divider Control	*/
		int	 RCKP: 1;  /* 18: Receiver Clock Polarity		*/
		int	 RFSP: 1;  /* 19: Receiver Frame Sync Polarity		*/
		int	RHCKP: 1;  /* 20: Receiver HF Clock Polarity		*/
		int	 RCKD: 1;  /* 21: Receiver Clock Source Direction	*/
		int	 RFSD: 1;  /* 22: Receiver Frame Sync Signal Dir	*/
		int	RHCKD: 1;  /* 23: HF Clock Direction			*/
	} B;

	int I;

} rccr_type;

typedef union				/* ESAI Receive Control Register	*/
{
	struct
	{	int	  RE0: 1;  /*  0: Receive #0 Enable			*/
		int	  RE1: 1;  /*  1: Receive #1 Enable			*/
		int	  RE2: 1;  /*  2: Receive #2 Enable			*/
		int	  RE3: 1;  /*  3: Receive #3 Enable			*/
		unsigned     : 2;  /*  4: Reserved				*/
		int	RSHFD: 1;  /*  6: Receiver Shift Direction		*/
		int	  RWA: 1;  /*  7: Receiver Word Alignment Control	*/
		unsigned RMOD: 2;  /*  8: Receiver Network Mode Control		*/
		unsigned RSWS: 5;  /* 10: Receiver Slot and Word Length Sel.	*/
		int	 RFSL: 1;  /* 15: Receiver Frame Sync Length		*/
		int	 RFSR: 1;  /* 16: Receiver Frame Sync Rel. Timing	*/
		unsigned     : 3;  /* 17: Reserved				*/
		int	 REIE: 1;  /* 20: Receive Exception Interrupt Enable	*/
		int	REDIE: 1;  /* 21: Receive Even Slot Data Int. Enable	*/
		int	  RIE: 1;  /* 22: Receive Interrupt Enable		*/
		int	 RLIE: 1;  /* 23: Receive Last Slot Interrupt Enable	*/
	} B;

	int I;

} rcr_type;

typedef union				/* ESAI Common Control Register		*/
{
	struct
	{	int	  OF0: 1;  /*  0: Serial Output Flag 0			*/
		int	  OF1: 1;  /*  1: Serial Output Flag 1			*/
		int	  OF2: 1;  /*  2: Serial Output Flag 2			*/
		unsigned     : 3;  /*  3: Reserved				*/
		int	  SYN: 1;  /*  6: Synchronous Mode Selection		*/
		int	 TEBE: 1;  /*  7: Transmitter External Buffer Enable	*/
		int	  ALC: 1;  /*  8: Alignment Control			*/
		unsigned     :15;  /*  9: Reserved				*/
	} B;

	int I;

} saicr_type;

typedef union				/* ESAI Status Register			*/
{
	struct
	{	int	  IF0: 1;  /*  0: Serial Input Flag 0			*/
		int	  IF1: 1;  /*  1: Serial Input Flag 1			*/
		int	  IF2: 1;  /*  2: Serial Input Flag 2			*/
		unsigned     : 3;  /*  3: Reserved				*/
		int	  RFS: 1;  /*  6: Receive Frame Sync Flag		*/
		int	  ROE: 1;  /*  7: Receiver Overrun Error Flag		*/
		int	  RDF: 1;  /*  8: Receive Data Register Full		*/
		int	 REDF: 1;  /*  9: Receive Even-Data Register Full	*/
		int	 RODF: 1;  /* 10: Receive Odd-Data Register Full	*/
		unsigned     : 2;  /* 11: Reserved				*/
		int	  TFS: 1;  /* 13: Transmit Frame Sync			*/
		int	  TUE: 1;  /* 14: Transmit Underrun Error Flag		*/
		int	  TDE: 1;  /* 15: Transmit Data Register Empty		*/
		int	 TEDE: 1;  /* 16: Transmit Even-Data Register Empty	*/
		int	 TODE: 1;  /* 17: Transmit Odd-Data Register Empty	*/
		unsigned     : 6;  /* 18: Reserved				*/
	} B;

	int I;

} saisr_type;


#define SAISR (*(const volatile saisr_type _X*)0xFFFFB3) /* ESAI Status Reg.    */
#define SAICR (*(saicr_type _X*)0xFFFFB4) /* ESAI Common Control Register     	*/
#define TCR   (*(tcr_type _X*)	0xFFFFB5) /* Transmit Control Register	      	*/
#define TCCR  (*(tccr_type _X*)	0xFFFFB6) /* Transmit Clock Control Register  	*/
#define RCR   (*(rcr_type _X*)	0xFFFFB7) /* Receive  Control Register	      	*/
#define RCCR  (*(rccr_type _X*)	0xFFFFB8) /* Receive  Clock Control Register  	*/
#define TSMA  (*(int _X*)	0xFFFFB9) /* ESAI Transmit Slot Mask Reg. A   	*/
#define TSMB  (*(int _X*)	0xFFFFBA) /* ESAI Transmit Slot Mask Reg. B   	*/
#define RSMA  (*(int _X*)	0xFFFFBB) /* ESAI Receive Slot Mask Reg. A    	*/
#define RSMB  (*(int _X*)	0xFFFFBC) /* ESAI Receive Slot Mask Reg. B    	*/

#define TX0   (*(volatile _fract _X*)	0xFFFFA0) /* Transmit Data Register 0	*/
#define TX1   (*(volatile _fract _X*)	0xFFFFA1) /* Transmit Data Register 1	*/
#define TX2   (*(volatile _fract _X*)	0xFFFFA2) /* Transmit Data Register 2	*/
#define TX3   (*(volatile _fract _X*)	0xFFFFA3) /* Transmit Data Register 3	*/
#define TX4   (*(volatile _fract _X*)	0xFFFFA4) /* Transmit Data Register 4	*/
#define TX5   (*(volatile _fract _X*)	0xFFFFA5) /* Transmit Data Register 5	*/

#define TSR   (*(int _X*)		0xFFFFA6) /* Time Slot Register	 	*/

#define RX0   (*(const volatile _fract _X*)0xFFFFA8) /* Receive Data Register 0 */
#define RX1   (*(const volatile _fract _X*)0xFFFFA9) /* Receive Data Register 1 */
#define RX2   (*(const volatile _fract _X*)0xFFFFAA) /* Receive Data Register 2 */
#define RX3   (*(const volatile _fract _X*)0xFFFFAB) /* Receive Data Register 3 */

/*--------------------------------------------------------------------------------

	ESAI_1

--------------------------------------------------------------------------------*/

#define SAISR_1 (*(const volatile saisr_type _X*)0xFFFF93) /* ESAI Status Reg.			*/
#define SAICR_1 (*(saicr_type _X*)0xFFFF94)		/* ESAI Common Control Register		*/
#define TCR_1   (*(tcr_type _X*)	0xFFFF95)	/* Transmit Control Register		*/
#define TCCR_1  (*(tccr_type _X*)	0xFFFF96)	/* Transmit Clock Control Register  	*/
#define RCR_1   (*(rcr_type _X*)	0xFFFF97)	/* Receive  Control Register		*/
#define RCCR_1  (*(rccr_type _X*)	0xFFFF98)	/* Receive  Clock Control Register  	*/
#define TSMA_1  (*(int _X*)	0xFFFF99) 		/* ESAI Transmit Slot Mask Reg. A   	*/
#define TSMB_1  (*(int _X*)	0xFFFF9A)		/* ESAI Transmit Slot Mask Reg. B   	*/
#define RSMA_1  (*(int _X*)	0xFFFF9B)		/* ESAI Receive Slot Mask Reg. A    	*/
#define RSMB_1  (*(int _X*)	0xFFFF9C)		/* ESAI Receive Slot Mask Reg. B    	*/

#define TX0_1   (*(volatile _fract _X*)	0xFFFF80)	/* Transmit Data Register 0		*/
#define TX1_1   (*(volatile _fract _X*)	0xFFFF81)	/* Transmit Data Register 1		*/
#define TX2_1   (*(volatile _fract _X*)	0xFFFF82)	/* Transmit Data Register 2		*/
#define TX3_1   (*(volatile _fract _X*)	0xFFFF83)	/* Transmit Data Register 3		*/
#define TX4_1   (*(volatile _fract _X*)	0xFFFF84)	/* Transmit Data Register 4		*/
#define TX5_1   (*(volatile _fract _X*)	0xFFFF85)	/* Transmit Data Register 5		*/

#define TSR_1   (*(int _X*)		0xFFFF86)	/* Time Slot Register	 		*/

#define RX0_1   (*(const volatile _fract _X*)0xFFFF88)	/* Receive Data Register 0		*/
#define RX1_1   (*(const volatile _fract _X*)0xFFFF89)	/* Receive Data Register 1		*/
#define RX2_1   (*(const volatile _fract _X*)0xFFFF8A)	/* Receive Data Register 2		*/
#define RX3_1   (*(const volatile _fract _X*)0xFFFF8B)	/* Receive Data Register 3		*/

/*--------------------------------------------------------------------------------

	EMUXR

--------------------------------------------------------------------------------*/

typedef union				/* ESAI MUX Control Register		*/
{
	struct
	{	int	  EMUX0: 1;/*  0: EMUX0					*/
		int	  EMUX1: 1;/*  1: EMUX1					*/
		int	  EMUX2: 1;/*  2: EMUX2					*/
		int	  EMUX3: 1;/*  3: EMUX3					*/
	} B;

	int I;

} emuxr_type;

#define EMUXR   (*(emuxr_type _X*)	0xFFFFAF)	/* ESAI MUX Control Register		*/
/*--------------------------------------------------------------------------------

	Port D

--------------------------------------------------------------------------------*/

#define PCRD  (*(int _X*)		0xFFFFD7) /* Port D Control Register	*/
#define PRRD  (*(int _X*)		0xFFFFD6) /* Port D Direction Register	*/
#define PDRD  (*(volatile int _X*)	0xFFFFD5) /* Port D GPIO Data Register	*/


/*--------------------------------------------------------------------------------

	DAX

--------------------------------------------------------------------------------*/

typedef union				/* DAX Non-Audio Data Register		*/
{
	struct
	{	unsigned     :10;  /*  0: Reserved				*/
		int	  XVA: 1;  /* 10: DAX Channel A Validity		*/
		int	  XUA: 1;  /* 11: DAX Channel A User Data		*/
		int	  XCA: 1;  /* 12: DAX Channel A Channel Status		*/
		int	  XVB: 1;  /* 13: DAX Channel B Validity		*/
		int	  XUB: 1;  /* 14: DAX Channel B User Data		*/
		int	  XCB: 1;  /* 15: DAX Channel B Channel Status		*/
		unsigned     : 8;  /* 16: Reserved				*/
	} B;

	int I;

} xnadr_type;

typedef union				/* DAX Control Register			*/
{
	struct
	{	int	 XDIE: 1;  /*  0: Audio Data Reg Empty Interrupt Enable */
		int	 XUIE: 1;  /*  1: Audio Data Underrun Interrupt Enable	*/
		int	 XBIE: 1;  /*  2: Block Transferred Interrupt Enable	*/
		unsigned  XCS: 2;  /*  3: DAX Clock Input Select		*/
		int	  XSB: 1;  /*  5: DAX Start Block			*/
		unsigned     :18;  /*  6: Reserved				*/
	} B;

	int I;

} xctr_type;

typedef union				/* DAX Status Register			*/
{
	struct
	{	int	 XADE: 1;  /*  0: DAX Audio Data Register Empty		*/
		int	 XAUR: 1;  /*  1: DAX Audio Data Underrun Error		*/
		int	 XBLK: 1;  /*  2: DAX Block Transfer Flag		*/
		unsigned     :21;  /*  3: Reserved				*/
	} B;

	int I;

} xstr_type;

#define XSTR  (*(const volatile xstr_type _X*) 0xFFFFD4) /* DAX Status Register */
#define XADRB (*(volatile _fract _X*)	0xFFFFD3)  /* DAX Audio Data Register B	*/
#define XADRA (*(volatile _fract _X*)	0xFFFFD2)  /* DAX Audio Data Register A	*/
#define XNADR (*(volatile xnadr_type _X*)0xFFFFD1) /* DAX Non-Audio Data Reg.   */
#define XCTR  (*(xctr_type _X*)		0xFFFFD0)  /* DAX Control Register	*/


/*--------------------------------------------------------------------------------

	Port E

--------------------------------------------------------------------------------*/

#define PCRE  (*(int _X*)		0xFFFF9F) /* Port E Control Register	*/
#define PRRE  (*(int _X*)		0xFFFF9E) /* Port E Direction Register	*/
#define PDRE  (*(volatile int _X*)	0xFFFF9D) /* Port E GPIO Data Register	*/


/*--------------------------------------------------------------------------------

	Triple Timer

--------------------------------------------------------------------------------*/

typedef union				/* Timer Prescaler Load Register	*/
{
	struct
	{
		unsigned PPV : 21; /*  0: Prescaler Preload Value		*/ 
		unsigned PCS :  2; /* 21: Prescaler Clock Source		*/
		int	     :  1; /* 23: Reserved				*/
	} B;

	int I;

} tplr_type;

typedef union				/* Timer Control/Status Register	*/
{
	struct
	{
		int	 TEN  : 1; /*  0: Timer Enable				*/
		int	 TOIE : 1; /*  1: Timer Overflow Interrupt Enable	*/
		int	 TCIE : 1; /*  2: Timer Compare Interrupt Enable	*/
		int	      : 1; /*  3: Reserved				*/
		unsigned TCTRL: 4; /*  4: Timer Control				*/
		int	 TINV : 1; /*  8: Timer Inverter			*/
		int	 TRM  : 1; /*  9: Timer Reload Mode			*/
		int	      : 1; /* 10: Reserved				*/
		int	 TDIR : 1; /* 11: Timer Direction			*/
		int	 TDI  : 1; /* 12: Timer Data Input			*/
		int	 TDO  : 1; /* 13: Timer Data Output			*/
		int	      : 1; /* 14: Reserved				*/
		int	 TPCE : 1; /* 15: Timer Prescaler Clock Enable		*/
		int	      : 4; /* 16: Reserved				*/
		int	 TOF  : 1; /* 20: Timer Overflow Flag			*/
		int	 TCF  : 1; /* 21: Timer Compare Flag			*/
		int	      : 2; /* 22: Reserved				*/
	} B;

	int I;

} tcsr_type;

#define TCSR0 (*(volatile tcsr_type _X*)  0xFFFF8F) /* Timer 0 Control/Status	*/
#define TLR0  (*(unsigned _X*)		  0xFFFF8E) /* Timer 0 Load Register	*/
#define TCPR0 (*(unsigned _X*)		  0xFFFF8D) /* Timer 0 Compare Register	*/
#define TCR0  (*(const volatile unsigned _X*)0xFFFF8C) /* Timer 0 Count Reg.    */

#define TCSR1 (*(volatile tcsr_type _X*)  0xFFFF8B) /* Timer 1 Control/Status 	*/
#define TLR1  (*(unsigned _X*)		  0xFFFF8A) /* Timer 1 Load Register	*/
#define TCPR1 (*(unsigned _X*)		  0xFFFF89) /* Timer 1 Compare Register	*/
#define TCR1  (*(const volatile unsigned _X*)0xFFFF88) /* Timer 1 Count Reg.	*/

#define TCSR2 (*(volatile tcsr_type _X*)  0xFFFF87) /* Timer 2 Control/Status 	*/
#define TLR2  (*(unsigned _X*)		  0xFFFF86) /* Timer 2 Load Register	*/
#define TCPR2 (*(unsigned _X*)		  0xFFFF85) /* Timer 2 Compare Register	*/
#define TCR2  (*(const volatile unsigned _X*)0xFFFF84) /* Timer 2 Count Reg.	*/

#define TPLR  (*(tplr_type _X*)		  0xFFFF83) /* Timer Prescaler Load Reg.*/
#define TPCR  (*(const volatile unsigned _X*)0xFFFF82) /* Timer Prescaler Count */


/*--------------------------------------------------------------------------------

	Exception Processing

--------------------------------------------------------------------------------*/

typedef union				/* Interrupt Priority Register Core	*/
{
	struct
	{	unsigned IAL : 2;  /*  0: IRQA Interrupt Priority Level		*/
		int	 IAT : 1;  /*  2: IRQA Trigger mode			*/
		unsigned IBL : 2;  /*  3: IRQB Interrupt Priority Level		*/
		int	 IBT : 1;  /*  5: IRQB Trigger mode			*/
		unsigned ICL : 2;  /*  6: IRQC Interrupt Priority Level		*/
		int	 ICT : 1;  /*  8: IRQC Trigger mode			*/
		unsigned IDL : 2;  /*  9: IRQD Interrupt Priority Level		*/
		int	 IDT : 1;  /* 11: IRQD Trigger mode			*/
		unsigned D0L : 2;  /* 12: DMA0 Interrupt Priority Level		*/
		unsigned D1L : 2;  /* 14: DMA1 Interrupt Priority Level		*/
		unsigned D2L : 2;  /* 16: DMA2 Interrupt Priority Level		*/
		unsigned D3L : 2;  /* 18: DMA3 Interrupt Priority Level		*/
		unsigned D4L : 2;  /* 20: DMA4 Interrupt Priority Level		*/
		unsigned D5L : 2;  /* 22: DMA5 Interrupt Priority Level		*/
	} B;

	int I;

} iprc_type;


typedef union				/* Interrupt Priority Register Periph.	*/
{
	struct
	{	unsigned HPL : 2;   /*	0: HI08	 Interrupt Priority Level	*/
		unsigned S0L : 2;   /*	2: ESSI0 Interrupt Priority Level	*/
		unsigned S1L : 2;   /*	4: ESSI1 Interrupt Priority Level	*/
		unsigned SCL : 2;   /*	6: SCI	 Interrupt Priority Level	*/
		unsigned T0L : 2;   /*	8: Timer Interrupt Priority Level	*/
		unsigned     : 14;  /* 10: Reserved				*/
	} B;

	int I;

} iprp_type;


#define IPRC  (*(iprc_type _X*) 0xFFFFFF) /* Interrupt Priority Register Core	*/
#define IPRP  (*(iprp_type _X*) 0xFFFFFE) /* Interrupt Priority Register Periph */

#endif	/* _REG56366_H */
